;BTS Install Script
;Written by Andr Gtze aka Jean Elcard, Phungus420 & James Nicholls aka NikNaks

;--------------------------------
;Include Modern UI

  !include "MUI2.nsh"

;--------------------------------
;Constants

  !define NAME "Your Super-duper Mod for BtS"
  !define VERSION "X.x.x"
  !define MOD_NAME "Your Mod"

  !define MOD_LOC "${MOD_NAME}"
  !define SHORT_NAME "${MOD_NAME}"

  !define BTSREGKEY "SOFTWARE\Firaxis Games\Sid Meier's Civilization 4 - Beyond the Sword"

  !define MYBTSDIR "C:\Program Files\Firaxis Games\Sid Meier's Civilization 4\Beyond the Sword"
  !define MYCLSDIR "C:\Program Files\Firaxis Games\Sid Meier's Civilization 4\Beyond the Sword\Mods\${MOD_LOC}"

  !define MYFILESDIR "${MYCLSDIR}"

  ;Source Code scripting removed
;--------------------------------
;General

  ;Name and file
  Name "${MOD_NAME}"
  OutFile "${NAME} v${VERSION}.exe"

  ;Default installation folder
  InstallDir ""

  ;Get installation folder from registry if available
  InstallDirRegKey HKLM "${BTSREGKEY}" "INSTALLDIR"

  ;Request application privileges for Windows Vista
  RequestExecutionLevel admin

;--------------------------------
;Custom Varaiables

  Var INSTDIR1 ; Mods

  Var CurrentPage ; important for directory verification

;--------------------------------

Function .onInit

  ReadRegStr $R0 HKLM \
  "Software\Microsoft\Windows\CurrentVersion\Uninstall\${MOD_NAME}" \
  "UninstallString"
  StrCmp $R0 "" done

  MessageBox MB_OKCANCEL|MB_ICONEXCLAMATION \
  "${NAME} is already installed. $\n$\nDo you wish to uninstall?." \
  IDOK uninst
  Abort

;Run the uninstaller
uninst:
  ClearErrors
  Exec "$INSTDIR\Mods\${MOD_LOC}\${MOD_NAME} Uninstall.exe"

done:

FunctionEnd

;--------------------------------
;Interface Settings

  !define MUI_ABORTWARNING
  !define MUI_UNABORTWARNING
  !define MUI_FINISHPAGE_NOAUTOCLOSE
  !define MUI_UNFINISHPAGE_NOAUTOCLOSE
  !define MUI_HEADERIMAGE

  ShowInstDetails show
  ShowUninstDetails show

;--------------------------------
;Pages

  !define MUI_CUSTOMFUNCTION_GUIINIT myOnGUIInit

  ; INSTALLER PAGES:

  !define MUI_WELCOMEPAGE_TITLE "Welcome to the Setup of ${SHORT_NAME} v${VERSION}"
  !define MUI_WELCOMEPAGE_TEXT "This wizard will guide you through the installation of ${NAME}.$\n$\n\
    Please ensure that Civilization 4 is not running while installing, \
    otherwise the installation may not work as expected.$\n$\nVersion ${VERSION}$\n$\nRequires Beyond the Sword: 3.17.$\n$\n\
    Click $\"Next$\" to continue."
  !insertmacro MUI_PAGE_WELCOME

  !define MUI_COMPONENTSPAGE_SMALLDESC
  !insertmacro MUI_PAGE_COMPONENTS

  !define MUI_DIRECTORYPAGE_VARIABLE $INSTDIR1
  !define MUI_PAGE_CUSTOMFUNCTION_PRE onInitDirectoryPage1
  !define MUI_PAGE_HEADER_TEXT "${NAME}"
  !define MUI_PAGE_HEADER_SUBTEXT "Please locate your $\"Beyond the Sword$\" folder"
  !define MUI_DIRECTORYPAGE_TEXT_TOP "Setup will install ${NAME} in the Mods folder of the folder below. $\n$\n\
    If the automatic folder detection should have failed, then type in or browse to the correct location. $\n$\n\
    Click Install to complete the installation."
  !define MUI_DIRECTORYPAGE_TEXT_DESTINATION "Your $\"Beyond the Sword$\" folder:"
  !insertmacro MUI_PAGE_DIRECTORY
  ;Source code scripting removed

  !insertmacro MUI_PAGE_INSTFILES

  !define MUI_FINISHPAGE_RUN "$INSTDIR1\Civ4BeyondSword.exe"
    !define MUI_FINISHPAGE_RUN_PARAMETERS "mod=\${MOD_NAME}"
    !define MUI_FINISHPAGE_RUN_NOTCHECKED
  !insertmacro MUI_PAGE_FINISH

    ;UN INSTALLER PAGES:

  !insertmacro MUI_UNPAGE_WELCOME
  !insertmacro MUI_UNPAGE_INSTFILES
  !insertmacro MUI_UNPAGE_FINISH

;--------------------------------
;Languages

  !insertmacro MUI_LANGUAGE "English"

  LangString DESC_Section1 ${LANG_ENGLISH} "Installs ${NAME} for Beyond the Sword."
  LangString DESC_Section4 ${LANG_ENGLISH} "Adds a shortcut on the Start Menu."
  LangString DESC_Section5 ${LANG_ENGLISH} "Creates a shortcut on the Desktop, allowing you to launch the mod \
                                            without the need to load BtS first."
  LangString DESC_Section6 ${LANG_ENGLISH} "Creates a shortcut on the Quick Launch bar, allowing you to launch \
                                            the mod directly from the task bar."

;--------------------------------
;Installer Sections
    ;the mod files itself:
  Section /o "${MOD_NAME} (required)" Section1
    SectionIn RO
    SetOutPath "$INSTDIR1\Mods\${MOD_LOC}"
    File /r "${MYFILESDIR}\*.*"
      ; write uninstall information to the registry
    WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${MOD_NAME}" "DisplayName" "${MOD_NAME} (remove only)"
    WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${MOD_NAME}" "UninstallString" "$INSTDIR1\Mods\${MOD_NAME}\${MOD_NAME} Uninstall.exe"
    WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${MOD_NAME}" "ModInstDir" "$INSTDIR1\Mods\"
    WriteUninstaller "$INSTDIR1\Mods\${MOD_NAME}\${MOD_NAME} Uninstall.exe"
  SectionEnd

  Section "Start Menu Shortcut" Section4
    CreateShortCut "$SMPROGRAMS\Firaxis Games\Sid Meier's Civilization 4 - Beyond the Sword\${NAME}.lnk" "$INSTDIR1\Civ4BeyondSword.exe" "mod=\${MOD_NAME}" "${MYCLSDIR}\${MOD_NAME}.ico" 0
  SectionEnd

  Section "Desktop Shortcut" Section5
    CreateShortCut "$DESKTOP\${NAME}.lnk" "$INSTDIR1\Civ4BeyondSword.exe" "mod=\${MOD_NAME}" "${MYCLSDIR}\${MOD_NAME}.ico" 0
  SectionEnd

  Section "Quick Launch Shortcut" Section6
    CreateShortCut "$QUICKLAUNCH\${NAME}.lnk" "$INSTDIR1\Civ4BeyondSword.exe" "mod=\${MOD_NAME}" "${MYCLSDIR}\${MOD_NAME}.ico" 0
  SectionEnd

  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${Section1}  $(DESC_Section1)
    !insertmacro MUI_DESCRIPTION_TEXT ${Section4}  $(DESC_Section4)
    !insertmacro MUI_DESCRIPTION_TEXT ${Section5}  $(DESC_Section5)
    !insertmacro MUI_DESCRIPTION_TEXT ${Section6}  $(DESC_Section6)
  !insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------
;--------------------------------
;Uninstaller Section

  Section "Uninstall"
    ;get mod install path of from the registy
    ReadRegStr $0 HKEY_LOCAL_MACHINE "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${MOD_NAME}" "ModInstDir"

    ;If you're writing an extension to another mod, you'll need to re-write this so that the original mod is not deleted when you un-install your addition
    ;Delete Files
    RMDir /r "$0\${MOD_NAME}\*.*"
    ;Remove the installation directory
    RMDir "$0\${MOD_NAME}"
    ;Delete Desktop Shortcut
    Delete "$DESKTOP\${NAME}.lnk"
    ;Delete Quicklaunch Shortcut
    Delete "$QUICKLAUNCH\${NAME}.lnk"
    ;Delete Start Menu Shortcut
    Delete "$SMPROGRAMS\Firaxis Games\Sid Meier's Civilization 4 - Beyond the Sword\${NAME}.lnk"
    ;Delete Unistall Registry Entries
    DeleteRegKey HKEY_LOCAL_MACHINE "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${MOD_NAME}"
  SectionEnd

;Installer Functions

  Function myOnGUIInit
    ;preselect CulturalLinked Starts
    SectionGetFlags ${Section1} $0
    IntOp $R0 $0 | ${SF_SELECTED}
    SectionSetFlags ${Section1} $R0
  FunctionEnd

  Function .onVerifyInstDir
    StrCmp $CurrentPage "DirectoryPage1" check1 valid
    check1:
      IfFileExists "$INSTDIR1\Civ4BeyondSword.exe" valid invalid
    valid:
      Return
    invalid:
      Abort
  FunctionEnd

  Function onInitDirectoryPage1
    StrCpy $CurrentPage "DirectoryPage1"
    ;Section 1 selected?
    SectionGetFlags ${Section1} $0
    IntOp $R0 $0 & ${SF_SELECTED}
    IntCmp $R0 ${SF_SELECTED} checkRegEntry
      Abort ;skip page
    checkRegEntry:
      StrCmp $INSTDIR "" 0 checkDefaultLocation
        StrCpy $INSTDIR1 "" ;we know nothing
        Return
      checkDefaultLocation:
          StrCpy $INSTDIR1 "$INSTDIR" ;found it!
  FunctionEnd
;--------------------------------